@@ -6,7 +6,7 @@ use IO::All;
 use List::Util 'uniq';
 use namespace::autoclean;
 
-our $VERSION = '0.1.4'; # VERSION:
+our $VERSION = '0.1.5'; # VERSION:
 # ABSTRACT: used to submit a batch of task to Torque cluster
 
 
@@ -45,7 +45,7 @@ has name => (
   default => sub { 'pbs' },
 );
 
-has task_running_num => (
+has parallel => (
   is  => 'rw',
   isa => 'Int',
   default => sub { '1' }
@@ -94,7 +94,7 @@ has stage => (
 
 sub execute {
   my $self = shift;
-  my $task_run_num = $self->task_running_num;
+  my $task_run_num = $self->parallel;
   my @tasks =  $self->all_tasks;
   my @stages = uniq (map { $_->priority } @tasks);
   for my $stage (@stages) {
@@ -144,7 +144,7 @@ Bioinfo::PBS::Queue - used to submit a batch of task to Torque cluster
 
 =head1 VERSION
 
-version 0.1.4
+version 0.1.5
 
 =head1 SYNOPSIS
 
@@ -156,6 +156,11 @@ version 0.1.4
     cmd => 'ls -alh; pwd',
   };
   my $pbs_obj = Bioinfo::PBS->new($para);
+
+  # three tasks are running at the same time
+  my $queue_obj = Bioinfo::PBS::Queue->new(name => 'blastnr', parallel => 3);
+
+  # all tasks will be running at the same time if parallel is not setted
   my $queue_obj = Bioinfo::PBS::Queue->new(name => 'blastnr');
   $queue_obj->add_tasks($pbs_obj);
   $queue_obj->add_tasks($pbs_obj);
